@@ -47,7 +47,7 @@ DEFAULT_EXTENSION_SETTINGS = {
     }
 };
 
-IS_FIREFOX = (typeof InstallTrigger !== "undefined"); // heh.
+IS_FIREFOX = (navigator && navigator.userAgent || '').toLowerCase().match(/(?:firefox|fxios)/) !== null;
 
 // NOTE if you change this, make sure to adjust the error message shown in action_popup.html
 SUPPORTED_PLATFORMS = ["linux", "openbsd", "freebsd"];
