@@ -151,6 +151,26 @@ function updateDependencies(control, extension, settingsKey) {
     }
 }
 
+function hasPermission(permission) {
+    return new Promise((resolve, reject) => {
+        chrome.permissions.contains({
+            permissions: [permission]
+        }, (result) => {
+            resolve(result);
+        });
+    });
+}
+
+function askPermission(permission) {
+    return new Promise((resolve, reject) => {
+        chrome.permissions.request({
+            permissions: [permission]
+        }, (result) => {
+            resolve(result);
+        });
+    });
+}
+
 document.addEventListener("DOMContentLoaded", function () {
 
     // poor man's tab widget :)
@@ -251,6 +271,29 @@ versionInfo.host);
         event.preventDefault();
     });
 
+    document.getElementById("request-permission-history").addEventListener("click", (e) => {
+        hasPermission("history").then((granted) => {
+            if (granted) {
+                document.getElementById("historyrunner-description").innerText = chrome.i18n.getMessage("permission_request_already");
+                return;
+            }
+
+            return askPermission("history");
+        });
+
+        e.preventDefault();
+    });
+
+    // When trying to enable historyrunner check if user accepted the permission
+    const historyRunnerCheckBox = document.querySelector("[data-extension=historyrunner][data-settings-key=enabled]");
+    historyRunnerCheckBox.addEventListener("click", (e) => {
+        if (historyRunnerCheckBox.checked) {
+            askPermission("history").then((granted) => {
+                historyRunnerCheckBox.checked = granted;
+            });
+        }
+    });
+
     // Make translators credit behave like the one in KAboutData
     var translatorsAboutData = "";
 
@@ -265,4 +308,12 @@ versionInfo.host);
     } else {
         translatorsAboutDataItem.style.display = "none";
     }
+
+    // Chrome at some point started not properly opening links on the options page
+    // Force external links to open in a new tab
+    document.querySelectorAll("a[href^=http]").forEach((link) => {
+        if (!link.target) {
+            link.target = "_blank";
+        }
+    });
 });
